summaryrefslogtreecommitdiff
path: root/symbian/PerlApp.h
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2005-10-26 18:50:08 +0300
committerH.Merijn Brand <h.m.brand@xs4all.nl>2005-10-26 12:37:47 +0000
commitc7a4d1c0391ba3d9736e90c66ae273d85847f9b0 (patch)
tree041acf92013ca87779ddc321763721535e45ad58 /symbian/PerlApp.h
parent65ff66fc0a6ee149618151ba533f4aac04969309 (diff)
downloadperl-c7a4d1c0391ba3d9736e90c66ae273d85847f9b0.tar.gz
Symbian: better Series 80 support
Message-ID: <B356D8F434D20B40A8CEDAEC305A1F24E7A6AA@esebe105.NOE.Nokia.com> p4raw-id: //depot/perl@25856
Diffstat (limited to 'symbian/PerlApp.h')
-rw-r--r--symbian/PerlApp.h66
1 files changed, 45 insertions, 21 deletions
diff --git a/symbian/PerlApp.h b/symbian/PerlApp.h
index 04cc0c7db5..8782fa0db5 100644
--- a/symbian/PerlApp.h
+++ b/symbian/PerlApp.h
@@ -17,32 +17,37 @@
# include <eikdoc.h>
# include <eikbctrl.h>
# include <eikgted.h>
+# include <eikdialg.h>
#endif /* #ifdef __SERIES60__ */
#include <coecntrl.h>
#include <f32file.h>
/* The source code can be compiled into "PerlApp" which is the simple
- * launchpad application/demonstrator, or into "PerlMin", which is the
- * minimal Perl launchpad application. Define the cpp symbols
- * PerlMin (a boolean), PerlMinUid (the Symbian application uid in
- * the 0x... format), and PerlMinName (a C wide string, with the L prefix)
- * to compile as "PerlMin". */
-
-#define PerlMinSample
-
-#ifdef PerlMinSample
-# define PerlMin
-# define PerlMinUid 0x102015F6
-# define PerlMinName L"PerlMin"
+ * launchpad application/demonstrator, or into "PerlAppMinimal", which
+ * is the minimal Perl launchpad application. Define the cpp symbols
+ * CreatePerlAppMinimal (a boolean), PerlAppMinimalUid (the Symbian
+ * application uid in the 0x... format), and PerlAppMinimalName (a C
+ * wide string, with the L prefix) to compile as "PerlAppMinimal". */
+
+// #define CreatePerlAppMinimal
+
+#ifdef CreatePerlAppMinimal
+# define PerlAppMinimal
+# ifndef PerlAppMinimalUid // PerlApp is ...F6, PerlRecog is ...F7
+# define PerlAppMinimalUid 0x102015F8
+# endif
+# ifndef PerlAppMinimalName
+# define PerlAppMinimalName L"PerlAppMinimal"
+# endif
#endif
#ifdef PerlMin
# ifndef PerlMinUid
# error PerlMin defined but PerlMinUid undefined
# endif
# ifndef PerlMinName
# error PerlMin defined but PerlMinName undefined
# endif
#endif
@@ -66,9 +71,9 @@ class CPerlAppDocument : public CMyDocument
{
public:
CPerlAppDocument(CEikApplication& aApp):CMyDocument(aApp) {;}
-#ifndef PerlMin
+#ifndef PerlAppMinimal
CFileStore* OpenFileL(TBool aDoOpen, const TDesC& aFilename, RFs& aFs);
-#endif // #ifndef PerlMin
+#endif // #ifndef PerlAppMinimal
private: // from CEikDocument
CEikAppUi* CreateAppUiL();
};
@@ -92,11 +97,11 @@ class CPerlAppUi : public CMyAppUi
~CPerlAppUi();
TBool ProcessCommandParametersL(TApaCommand aCommand, TFileName& aDocumentName, const TDesC8& aTail);
void HandleCommandL(TInt aCommand);
-#ifndef PerlMin
+#ifndef PerlAppMinimal
void OpenFileL(const TDesC& aFileName);
void InstallOrRunL(const TFileName& aFileName);
void SetFs(const RFs& aFs);
-#endif // #ifndef PerlMin
+#endif // #ifndef PerlAppMinimal
TBuf<KPerlAppOneLinerSize> iOneLiner; // Perl source code to evaluate.
CPerlAppView* iAppView;
private:
@@ -117,4 +122,23 @@ class CPerlAppView : public CMyAppView
void ConstructL(const TRect& aRect);
};
+#ifdef __SERIES80__
+
+class CPerlAppTextQueryDialog : public CEikDialog
+{
+ public:
+ CPerlAppTextQueryDialog(HBufC*& aBuffer);
+ /* TODO: OfferKeyEventL() so that newline can be seen as 'OK'. */
+ HBufC*& iData;
+ TPtrC iTitle; // used in S80 but not in S60
+ TPtrC iPrompt; // used in S60 and S80
+ TInt iMaxLength;
+ protected:
+ void PreLayoutDynInitL();
+ private:
+ TBool OkToExitL(TInt aKeycode);
+};
+
+#endif /* #ifdef __SERIES80__ */
+
#endif // __PerlApp_h__
@@ -17,32 +17,37 @@
#endif
-#ifdef PerlMin
-# ifndef PerlMinUid
-# error PerlMin defined but PerlMinUid undefined
+#ifdef PerlAppMinimal
+# ifndef PerlAppMinimalUid
+# error PerlAppMinimal defined but PerlAppMinimalUid undefined
# endif
@@ -17,32 +17,37 @@
# endif
-# ifndef PerlMinName
-# error PerlMin defined but PerlMinName undefined
+# ifndef PerlAppMinimalName
+# error PerlAppMinimal defined but PerlAppMinimalName undefined
# endif
#endif